# Example Menu

Some description.
Tags and amounts depend on recipes.

---

## Main course

- *4 l* [Kartoffeltopf](griechischer_kartoffeltopf.md)
- *1* [Brot](schwarzbierbrot.md)

## Dessert

- *40 l* Ice Cream

---

Text with description for the meta recipe and how to prepare it.

